%define sbcl_shell /bin/bash

# threading support
%define threads 1
%{?_without_threads: %{expand: %%global threads 0}}

%define bootstrap 0
%{?_with_bootstrap: %{expand: %%global bootstrap 1}}

Name: 	 sbcl
Version: 1.0.47
Release: %mkrel 1
Summary: Steel Bank Common Lisp compiler and runtime system
License: BSD
Group:   Development/Other
URL:     http://sbcl.sourceforge.net/
Source0: http://downloads.sourceforge.net/project/sbcl/sbcl/1.0.47/sbcl-1.0.47-source.tar.bz2
#%if %{bootstrap}
#Source1: http://prdownloads.sourceforge.net/sbcl/%{name}-%{version}-x86-linux-binary.tar.bz2
#Source2: http://prdownloads.sourceforge.net/sbcl/%{name}-%{version}-x86-64-linux-binary.tar.bz2
#%endif
Source3: customize-target-features.lisp 
Patch1: sbcl-1.0.45-default-sbcl-home.patch
Patch2: sbcl-0.9.5-personality.patch
Patch3: sbcl-1.0.28-optflags.patch
Patch4: sbcl-0.9.17-LIB_DIR.patch
Patch5: sbcl-1.0.16-GNU_SOURCE.patch
# Allow override of contrib test failure(s)
Patch7: sbcl-1.0.2-permissive.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}

Requires(post): /sbin/install-info
Requires(preun): /sbin/install-info
# doc generation
BuildRequires: ghostscript
BuildRequires: texinfo
BuildRequires: time
%if ! %{bootstrap}
BuildRequires: sbcl
%endif

%description
Steel Bank Common Lisp (SBCL) is a Open Source development environment
for Common Lisp. It includes an integrated native compiler,
interpreter, and debugger.


%prep
%if %{bootstrap}
%ifarch x86_64
echo x86_64
%define sbcl_arch x86_64
%setup -q -a 2
%define drbin %{name}-%{version}
%endif

%ifarch %{ix86}
echo ix86
%define sbcl_arch x86
%setup -q -a 1
%define dirbin %{name}-%{version}-%{sbcl_arch}-linux
%endif

mkdir sbcl-bootstrap
pushd %{dirbin}
INSTALL_ROOT=`pwd`/../sbcl-bootstrap %{?sbcl_shell} ./install.sh
popd
%else
%setup -q
%endif

%patch1 -p1 -b .default-sbcl-home
%patch2 -p1 -b .personality
%patch3 -p1 -b .optflags
%patch4 -p1 -b .LIB_DIR
%patch5 -p2 -b .GNU_SOURCE
%patch7 -p1 -b .permissive

%if %{threads}
install -m644 -p %{SOURCE3} ./customize-target-features.lisp
%endif

%build
%if %{bootstrap}
export SBCL_HOME=`pwd`/sbcl-bootstrap/lib/sbcl
export PATH=`pwd`/sbcl-bootstrap/bin:${PATH}
%endif

export SBCL_HOME=%{_libdir}/sbcl
export DEFAULT_SBCL_HOME=%{_libdir}/sbcl
export RPM_OPT_FLAGS=$(echo %optflags | sed -e "s/-fomit-frame-pointer//")
sh make.sh

make -C doc/manual html info

%install
rm -rf %{buildroot}

mkdir -p %{buildroot}{%{_bindir},%{_libdir},%{_mandir}}

unset SBCL_HOME 
export INSTALL_ROOT=%{buildroot}%{_prefix} 
export LIB_DIR=%{buildroot}%{_libdir} 
sh install.sh 

## Unpackaged files
rm -rf %{buildroot}%{_docdir}/sbcl
rm -f  %{buildroot}%{_infodir}/dir
# CVS crud 
find %{buildroot} -name CVS -type d | xargs rm -rf
find %{buildroot} -name .cvsignore | xargs rm -f
# 'test-passed' files from %%check
find %{buildroot} -name 'test-passed' | xargs rm -vf

%post
for info in sbcl.info sbcl.info-1 sbcl.info-2 asdf.info; do
    /sbin/install-info %{_infodir}/${info}* %{_infodir}/dir ||:
done

%postun
for info in sbcl.info sbcl.info-1 sbcl.info-2 asdf.info; do
    /sbin/install-info --delete %{_infodir}/${info}* %{_infodir}/dir ||:
done

%pre
# min_bootstrap: We *could* check for only-on-upgrade, but why bother?   (-:
for info in sbcl.info sbcl.info-1 sbcl.info-2 asdf.info; do
    /sbin/install-info --delete %{_infodir}/${info}* %{_infodir}/dir >& /dev/null ||:
done

%files
%defattr(-,root,root)
%doc BUGS COPYING README CREDITS NEWS TLA TODO
%doc STYLE PRINCIPLES
%{_bindir}/*
%{_libdir}/sbcl/
%{_mandir}/man?/*
%doc doc/manual/
%{_infodir}/*

%clean
rm -rf %{buildroot}


%changelog
* Mon Apr 11 2011 Paulo Andrade <pcpa@mandriva.com.br> 1.0.47-1mdv2011.0
+ Revision: 652674
- Update to sbcl 1.0.47

* Sat Mar 05 2011 Funda Wang <fwang@mandriva.org> 1.0.46-1
+ Revision: 642157
- New version 1.0.4on 6

* Sat Mar 05 2011 Funda Wang <fwang@mandriva.org> 1.0.45-5
+ Revision: 642116
- rebuild to obsolete old packages

* Mon Feb 07 2011 Paulo Andrade <pcpa@mandriva.com.br> 1.0.45-3
+ Revision: 636712
- Correct rpm script for istall/remove of info files

* Wed Feb 02 2011 Paulo Andrade <pcpa@mandriva.com.br> 1.0.45-2
+ Revision: 635347
- Rediff patch1 and remove logic to rename a very long named file

* Thu Jan 27 2011 Shlomi Fish <shlomif@mandriva.org> 1.0.45-1
+ Revision: 633274
- Upgrade to 1.0.45

  + Paulo Andrade <pcpa@mandriva.com.br>
    - Update to version 1.0.40

* Mon Apr 19 2010 Frederik Himpe <fhimpe@mandriva.org> 1.0.37-1mdv2010.1
+ Revision: 536788
- update to new version 1.0.37

* Wed Mar 03 2010 Frederik Himpe <fhimpe@mandriva.org> 1.0.36-1mdv2010.1
+ Revision: 513976
- Update to new version 1.0.36

* Fri Feb 05 2010 Frederik Himpe <fhimpe@mandriva.org> 1.0.35-1mdv2010.1
+ Revision: 501257
- update to new version 1.0.35

* Fri Jan 01 2010 Frederik Himpe <fhimpe@mandriva.org> 1.0.34-1mdv2010.1
+ Revision: 484862
- update to new version 1.0.34

* Sat Nov 28 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.33-1mdv2010.1
+ Revision: 470717
- update to new version 1.0.33

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.32-1mdv2010.1
+ Revision: 462185
- update to new version 1.0.32

* Sat Aug 29 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.31-1mdv2010.0
+ Revision: 422325
- update to new version 1.0.31

* Wed Jul 29 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.30-1mdv2010.0
+ Revision: 404229
- Update to new version 1.0.30

* Thu Jun 04 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.29-1mdv2010.0
+ Revision: 382863
- Update to new version 1.0.29
- Updated optflags patch from Fedora

* Tue Mar 10 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.26-1mdv2009.1
+ Revision: 353466
- Update to new version 1.0.26

* Thu Feb 05 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.25-1mdv2009.1
+ Revision: 337955
- Update to new version 1.0.25
- New default-sbcl-home patch from Fedora

* Mon Jan 05 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.24-1mdv2009.1
+ Revision: 325080
- Update to new version 1.0.24

* Fri Dec 05 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.23-1mdv2009.1
+ Revision: 310915
- update to new version 1.0.23

* Fri Oct 31 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.22-1mdv2009.1
+ Revision: 299035
- update to new version 1.0.22

* Sat Oct 11 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.21-1mdv2009.1
+ Revision: 291698
- update to new version 1.0.21

* Tue Sep 02 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.20-1mdv2009.0
+ Revision: 279327
- Update to new version 1.0.20

* Tue Sep 02 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.19-3mdv2009.0
+ Revision: 279242
- Really enable multi-threading now by fixing two typos

* Sun Aug 31 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.19-2mdv2009.0
+ Revision: 277887
- Now that sbcl is bootstrapped in Mandriva, build with the sbcl rpm
  package as BuildRequires.
- Remove the binary source packages from the SRPM
- Don't compile with -fomit-frame-pointer, it's needed for debugging

* Sun Aug 31 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.19-1mdv2009.0
+ Revision: 277842
- import sbcl


